@@ -1,6 +1,7 @@
 from .Base import Base
 from .JsonEnum import JsonEnum
 from .utils import String
+from .SchemaEntry import SchemaEntry
 from .FileFormatSettings import FileFormatSettings
 
 class CsvQuoteStyle(JsonEnum):
@@ -14,12 +15,16 @@ class CsvStyle(JsonEnum):
 
 
 class CsvFormatSettings(FileFormatSettings):
-    def __init__(self, schema=[], columnHeaders=False, delimiter=","):
+    def __init__(self, schema=[]):
         self.schema = schema + [
-            SchemaEntry("$type", String, "CsvFormatSettings"),
-            SchemaEntry("columnHeaders", bool, columnHeaders),
-            SchemaEntry("delimiter", String, delimiter),
-            SchemaEntry("quoteStyle", CsvQuoteStyle, CsvQuoteStyle.Csv),
-            SchemaEntry("csvStyle", CsvStyle, CsvStyle.QuoteAlways),
+            SchemaEntry("columnHeaders", bool),
+            SchemaEntry("delimiter", String),
+            SchemaEntry("quoteStyle", CsvQuoteStyle),
+            SchemaEntry("csvStyle", CsvStyle),
         ]
         super().__init__(self.schema)
+
+    def toJson(self):
+        entity = super().toJson()
+        entity["$type"] = "CsvFormatSettings"
+        return entity
